Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/mumble-voip/mumble.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
Diffstat (limited to 'src/QtUtils.h')
-rw-r--r--src/QtUtils.h33
1 files changed, 25 insertions, 8 deletions
diff --git a/src/QtUtils.h b/src/QtUtils.h
index d53c243c0..74a3808b4 100644
--- a/src/QtUtils.h
+++ b/src/QtUtils.h
@@ -6,15 +6,32 @@
#ifndef MUMBLE_QTUTILS_H_
#define MUMBLE_QTUTILS_H_
+#include <QString>
+
class QObject;
+class QStringList;
+
+namespace Mumble {
+namespace QtUtils {
+
+ /**
+ * A deleter function to be used for QObjects that must not be deleted using
+ * delete directly but rather by calling deleteLater() on them (and thus letting
+ * Qt perform the actual deletion).
+ *
+ * This function is intended to be used in smart-pointers holding QObjects.
+ */
+ void deleteQObject(QObject *object);
+
+ QString decode_utf8_qssl_string(const QString &input);
+
+ /**
+ * Applies decode_utf8_qssl_string on the first element in the
+ * given list. If the list is empty an empty String is returned.
+ */
+ QString decode_first_utf8_qssl_string(const QStringList &list);
-/**
- * A deleter function to be used for QObjects that must not be deleted using
- * delete directly but rather by calling deleteLater() on them (and thus letting
- * Qt perform the actual deletion).
- *
- * This function is intended to be used in smart-pointers holding QObjects.
- */
-void deleteQObject(QObject *object);
+}; // namespace QtUtils
+}; // namespace Mumble
#endif // MUMBLE_QTUTILS_H_